==> xcsoar-6.8.8.tar.xz: xcsoar-6.8.8/python/src/Flight/IGCFixEnhanced.hpp <==
/* Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef PYTHON_IGC_FIX_ENHANCED_HPP
#define PYTHON_IGC_FIX_ENHANCED_HPP

#include "IGC/IGCFix.hpp"
#include "Time/BrokenDate.hpp"
#include "NMEA/Info.hpp"
#include "NMEA/Derived.hpp"

struct IGCFixEnhanced : public IGCFix
{
  BrokenDate date;

  unsigned clock;

  /* The detail level of this fix. -1 is not visible at all, 0 is always visible. */
  int level;

  /* Terrian elevation */
  int elevation;

  bool Apply(const NMEAInfo &basic, const DerivedInfo &calculated) {
    if (IGCFix::Apply(basic)) {
      date = basic.date_time_utc;
      clock = basic.time;

      if (calculated.terrain_valid)
        elevation = calculated.terrain_altitude;
      else
        elevation = -1000;

      return true;
    } else {
      return false;
    }
  };

  void Clear() {
    time = BrokenTime::Invalid();
    elevation = -1000;
    level = 0;
    ClearExtensions();
  };
};

#endif /* PYTHON_IGC_FIX_ENHANCED_HPP */

==> xcsoar-7.13.tar.xz: xcsoar-7.13/python/src/Flight/IGCFixEnhanced.hpp <==
/* Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef PYTHON_IGC_FIX_ENHANCED_HPP
#define PYTHON_IGC_FIX_ENHANCED_HPP

#include "IGC/IGCFix.hpp"
#include "time/BrokenDate.hpp"
#include "NMEA/Info.hpp"
#include "NMEA/Derived.hpp"

struct IGCFixEnhanced : public IGCFix
{
  BrokenDate date;

  unsigned clock;

  /* The detail level of this fix. -1 is not visible at all, 0 is always visible. */
  int level;

  /* Terrian elevation */
  int elevation;

  bool Apply(const NMEAInfo &basic, const DerivedInfo &calculated) {
    if (IGCFix::Apply(basic)) {
      date = basic.date_time_utc;
      clock = basic.time;

      if (calculated.terrain_valid)
        elevation = calculated.terrain_altitude;
      else
        elevation = -1000;

      return true;
    } else {
      return false;
    }
  };

  void Clear() {
    time = BrokenTime::Invalid();
    elevation = -1000;
    level = 0;
    ClearExtensions();
  };
};

#endif /* PYTHON_IGC_FIX_ENHANCED_HPP */
